import { ServiceLogger } from "@effect-aws/commons";
import { Effect, FiberRef, Layer } from "effect";
import { dual } from "effect/Function";
import { globalValue } from "effect/GlobalValue";
/**
 * @since 1.0.0
 * @category iam service config
 */
const currentIAMServiceConfig = globalValue("@effect-aws/client-iam/currentIAMServiceConfig", () => FiberRef.unsafeMake({}));
/**
 * @since 1.0.0
 * @category iam service config
 */
export const withIAMServiceConfig = dual(2, (effect, config) => Effect.locally(effect, currentIAMServiceConfig, config));
/**
 * @since 1.0.0
 * @category iam service config
 */
export const setIAMServiceConfig = (config) => Layer.locallyScoped(currentIAMServiceConfig, config);
/**
 * @since 1.0.0
 * @category adapters
 */
export const toIAMClientConfig = Effect.gen(function* () {
    const { logger: serviceLogger, ...config } = yield* FiberRef.get(currentIAMServiceConfig);
    const logger = serviceLogger === true
        ? yield* ServiceLogger.toClientLogger(ServiceLogger.defaultServiceLogger)
        : (serviceLogger ? yield* ServiceLogger.toClientLogger(ServiceLogger.make(serviceLogger)) : undefined);
    return { logger, ...config };
});
//# sourceMappingURL=IAMServiceConfig.js.map